@@ -1,3 +1,4 @@
+from textwrap import wrap
 from nebula.graph import ttypes,GraphService
 from nebula.ConnectionPool import ConnectionPool
 from nebula.Client import GraphClient
@@ -429,11 +430,13 @@ def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="
     return VESchema
 
 def ucreateGDB(gClient,gdbname):
+    '''创建图数据库'''
     gClient.execute_query("CREATE SPACE {}".format(gdbname))
     
 def ucreateTag(gClient,tagAttrTypeDefaultDict,defaultTagAttrTypeDict={"Alias":{"Name":{"type":"string","default":"null"},
                                                                                 "checked":{"type":"string","default":"false"},
                                                                                 "from_kg":{"type":"string","default":""}}}):
+    '''创建标签'''
     for tagTypeItem in tagAttrTypeDefaultDict:
         attrList=["{} {} DEFAULT {}".format(attrNameKeyItem,
                                                 tagAttrTypeDefaultDict[attrNameKeyItem]["type"],
@@ -443,6 +446,7 @@ def ucreateTag(gClient,tagAttrTypeDefaultDict,defaultTagAttrTypeDict={"Alias":{"
 
 def ucreateEdge(gClient,edgeAttrTypeDefaultDict,defaultEdgeAttrTypeDict={"alias":{"checked":{"type":"string","default":"false"},
                                                                                 "from_kg":{"type":"string","default":""}}}):
+    '''创建边'''
     for tagTypeItem in edgeAttrTypeDefaultDict:
         attrList=["{} {} DEFAULT {}".format(attrNameKeyItem,
                                                 edgeAttrTypeDefaultDict[attrNameKeyItem]["type"],
@@ -450,6 +454,133 @@ def ucreateEdge(gClient,edgeAttrTypeDefaultDict,defaultEdgeAttrTypeDict={"alias"
         attrListStr=",".join(attrList)
         gClient.execute_query("CREATE EDGE IF NOT EXISTS {} ({})".format(tagTypeItem,attrListStr))
 
+def downloadGraph(gClient,
+                    srcGdbName,srcFakeGdbName,
+                    edgeTypeList=[],
+                    srcVertexKeynameDict={"srcNodeType":"srcNodeIdAttr"}):
+    
+    '''以上传的格式下载图数据'''
+    if "downloadGraph" not in os.listdir("."):
+        os.mkdir("downloadGraph")
+    rawSchema={"gDbName":srcFakeGdbName,"vertex":[],"edge":[]}
+    gClient.execute_query("USE {}".format(srcGdbName))
+    uploadFolderName="tmp_{}".format(int(time.time()*1000))
+    if uploadFolderName not in os.listdir("./downloadGraph"):
+        os.mkdir("./downloadGraph/"+uploadFolderName)
+    for srcVertexTypeItem in srcVertexKeynameDict:
+        lookupVertexGroupStr="LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}!='不可能的名字'|FETCH PROP ON {nodeType} $-.VertexID".format(
+                                                                                                                                                nodeType=srcVertexTypeItem,
+                                                                                                                                                nodeIdAttr=srcVertexKeynameDict[srcVertexTypeItem]
+                                                                                                                                            )
+        vertexDfItem=wrapNebula2Df(gClient.execute_query(lookupVertexGroupStr))
+        renameColumnDict=dict((colItem,colItem.split(".")[1])
+                                if "." in colItem else (colItem,colItem) 
+                                for colItem in vertexDfItem.columns)
+        vertexDfItem.rename(renameColumnDict,axis=1,inplace=True)
+        
+        vertexAttrDTypeDf=wrapNebula2Df(gClient.execute_query("DESCRIBE TAG {}".format(srcVertexTypeItem)))
+        vertexAttrList=vertexAttrDTypeDf["Field"].values.flatten().tolist()
+        # csv2platodb
+        csv2platoDBAttrDict=dict((colItem,colItem) for colItem in vertexDfItem.columns if colItem not in vertexAttrList)
+        
+        # platoAttrType
+        attrDTypeDict=dict(vertexAttrDTypeDf.values.tolist())
+        for colItem in vertexDfItem.columns:
+            if colItem in attrDTypeDict:
+                if attrDTypeDict[colItem]=="string":
+                    vertexDfItem[colItem].fillna("null",inplace=True)
+                    vertexDfItem[colItem]=vertexDfItem[colItem].astype(str)
+                elif attrDTypeDict[colItem]=="int":
+                    vertexDfItem[colItem].fillna(0,inplace=True)
+                    vertexDfItem[colItem]=vertexDfItem[colItem].astype(int)
+                elif attrDTypeDict[colItem]=="double":
+                    vertexDfItem[colItem].fillna(0.0,inplace=True)
+                    vertexDfItem[colItem]=vertexDfItem[colItem].astype(float)
+        
+        vertexDfItem.to_csv("./downloadGraph/{}/{}.csv".format(uploadFolderName,srcVertexTypeItem),index=None)
+        vertexSchemaItem={
+                            "cover_label":"escape,cover",
+                            "file_name":"{}.csv".format(srcVertexTypeItem),
+                            "node_type":srcVertexTypeItem,
+                            "id_col":srcVertexKeynameDict[srcVertexTypeItem], 
+                            "csv2plato_attr_map":csv2platoDBAttrDict,
+                            "attr_type_map":attrDTypeDict
+                        }
+        rawSchema["vertex"].append(vertexSchemaItem)
+        
+    for edgeTypeItem in edgeTypeList:
+        for srcVertexTypeItem_head in srcVertexKeynameDict:
+            for tgtVertexTypeItem_tail in srcVertexKeynameDict:
+                edgeLookupReq=gClient.execute_query("LOOKUP ON {srcNodeType} WHERE {srcNodeType}.{srcNodeIdAttr}!='不可能的名字'|\
+                                                        GO FROM $-.VertexID OVER {edgeType} YIELD   {edgeType}._src AS srcSysID,\
+                                                                                                    {edgeType}._dst AS tgtSysID,\
+                                                                                                    $^.{srcNodeType}.{srcNodeIdAttr} AS {srcNodeType}{srcNodeIdAttr}_head,\
+                                                                                                    $$.{tgtNodeType}.{tgtNodeIdAttr} AS {tgtNodeType}{tgtNodeIdAttr}_tail".format(
+                                                                                                        srcNodeType=srcVertexTypeItem_head,
+                                                                                                        srcNodeIdAttr=srcVertexKeynameDict[srcVertexTypeItem_head],
+                                                                                                        edgeType=edgeTypeItem,
+                                                                                                        tgtNodeType=tgtVertexTypeItem_tail,
+                                                                                                        tgtNodeIdAttr=srcVertexKeynameDict[tgtVertexTypeItem_tail]
+                                                                                                    ))
+                edgeLookupDf=wrapNebula2Df(edgeLookupReq).dropna()
+                
+                edgeSysIdList=edgeLookupDf.loc[:,["srcSysID","tgtSysID"]].astype(str).values.tolist()
+                edgeSysIdListStr=",".join(["->".join(edgeSysIdItem) for edgeSysIdItem in edgeSysIdList])
+                edgeFetchReq=gClient.execute_query("FETCH PROP ON {edgeType} {edgeList}".format(
+                                                                                                    edgeType=edgeTypeItem,
+                                                                                                    edgeList=edgeSysIdListStr
+                                                                                                ))
+                edgeFetchDf=wrapNebula2Df(edgeFetchReq)
+                
+                edgeDfItem=pd.merge(edgeLookupDf,edgeFetchDf,
+                                    left_on=["srcSysID","tgtSysID"],
+                                    right_on=["{edgeType}._src".format(edgeType=edgeTypeItem),
+                                              "{edgeType}._dst".format(edgeType=edgeTypeItem)])
+                renameColDict=dict((colItem,colItem.split(".")[1])
+                                    if "." in colItem else (colItem,colItem)
+                                    for colItem in edgeDfItem.columns)
+                edgeDfItem.rename(renameColDict,axis=1,inplace=True)
+                
+                edgeAttrDTypeDf=wrapNebula2Df(gClient.execute_query("DESCRIBE EDGE {}".format(edgeTypeItem)))
+                edgeAttrList=edgeAttrDTypeDf["Field"].values.flatten().tolist()
+                # csv2platodb
+                csv2platoAttrDict=dict((colItem,colItem) for colItem in vertexDfItem.columns  if colItem in edgeAttrList)
+                
+                # platoAttrType
+                attrDTypeDict=dict(edgeAttrDTypeDf.values.tolist())
+                for colItem in edgeDfItem.columns:
+                    if colItem in attrDTypeDict:
+                        if attrDTypeDict[colItem]=="string":
+                            edgeDfItem[colItem].fillna("null",inplace=True)
+                            edgeDfItem[colItem]=edgeDfItem[colItem].astype(str)
+                        elif attrDTypeDict[colItem]=="int":
+                            edgeDfItem[colItem].fillna(0,inplace=True)
+                            edgeDfItem[colItem]=edgeDfItem[colItem].astype(int)
+                        elif attrDTypeDict[colItem]=="double":
+                            edgeDfItem[colItem].fillna(0.0,inplace=True)
+                            edgeDfItem[colItem]=edgeDfItem[colItem].astype(float)
+                
+                edgeDfItem.to_csv("./downloadGraph/{}/{}.csv".format(uploadFolderName,edgeTypeItem),index=None)
+                edgeSchemaItem={
+                    "cover_label":"escape,escape,cover",
+                    "file_name":"{}.csv".format(edgeTypeItem),
+                    "edge_type":edgeTypeItem,
+                    "src_type":srcVertexTypeItem_head,
+                    "tgt_type":tgtVertexTypeItem_tail,
+                    "src_id":"{srcNodeType}{srcNodeIdAttr}_head".format(srcNodeType=srcVertexTypeItem_head,srcNodeIdAttr=srcVertexKeynameDict[srcVertexTypeItem_head]),
+                    "tgt_id":"{tgtNodeType}{tgtNodeIdAttr}_tail".format(tgtNodeType=tgtVertexTypeItem_tail,tgtNodeIdAttr=srcVertexKeynameDict[tgtVertexTypeItem_tail]),
+                    "csv2plato_attr_map":csv2platoAttrDict,
+                    "attr_type_map":attrDTypeDict
+                }
+                
+                rawSchema["edge"].append(edgeSchemaItem)
+                
+    
+    with open("./downloadGraph/{}/rawSchema.json".format(uploadFolderName),"w+") as rawSchemaFile:
+        json.dump(rawSchema,rawSchemaFile)
+        
+
+
 if __name__=="__main__":
     
     srcGHost="9.135.95.249"
@@ -458,10 +589,10 @@ if __name__=="__main__":
     srcGPassword="nebula"
     srcGdbName="post_dept_char_major_skill__wliangwang"
     
-    # srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
-    # srcClient = GraphClient(srcConnection_pool)
-    # srcClient.authenticate(srcGUser, srcGPassword)
-    # srcClient.execute_query("use {}".format(srcGdbName))
+    srcConnection_pool = ConnectionPool(srcGHost, srcGPort,network_timeout=300000)
+    srcClient = GraphClient(srcConnection_pool)
+    srcClient.authenticate(srcGUser, srcGPassword)
+    srcClient.execute_query("use {}".format(srcGdbName))
     
     # start=time.time()
     # adf=wrapNebula2Df(srcClient.execute_query("LOOKUP ON Token WHERE Token.TokenName=='深'|GO FROM $-.VertexID OVER consistOf REVERSELY YIELD consistOf._dst AS tailSysId,$$.Company.CompanyName AS CompanyName,consistOf.weight AS weight|    ORDER BY $-.weight DESC|LIMIT 50 UNION \
@@ -480,35 +611,38 @@ if __name__=="__main__":
     
     # print(adf.head())
     
-    srcVertexKeynameDict={
-        "Skill":"SkillName"
-    }
-    edgeTypeList=["relate"]
+    # srcVertexKeynameDict={
+    #     "Skill":"SkillName"
+    # }
+    # edgeTypeList=["relate"]
 
-    gHost="9.135.95.249"
-    gPort=13708
-    gUser="root"
-    gPassword="nebula"
-    srcGdbName="post_dept_char_major_skill__wliangwang"
-    tgtGdbName="post_skill_school_ianxu"
-    tgtGAPIUrl="http://{}:8083".format("9.135.95.249")
+    # gHost="9.135.95.249"
+    # gPort=13708
+    # gUser="root"
+    # gPassword="nebula"
+    # srcGdbName="post_dept_char_major_skill__wliangwang"
+    # tgtGdbName="post_skill_school_ianxu"
+    # tgtGAPIUrl="http://{}:8083".format("9.135.95.249")
     
-    projectName="transfer_skills"
+    # projectName="transfer_skills"
 
-    batchSize=1024
-    myDfList=[]
+    # batchSize=1024
+    # myDfList=[]
 
-    csv2platoDTypeDict={
-        "object":"string",
-        "float64":"double",
-        "int64":"int",
-    }
+    # csv2platoDTypeDict={
+    #     "object":"string",
+    #     "float64":"double",
+    #     "int64":"int",
+    # }
     
-    transferBetweenPlato(gHost,gPort,gUser,gPassword,
-                         srcGdbName,tgtGdbName,tgtGAPIUrl,
-                         edgeTypeList=edgeTypeList,
-                         srcVertexKeynameDict=srcVertexKeynameDict,
-                         csv2platoDTypeDict=csv2platoDTypeDict,
-                         projectName=projectName)
+    # transferBetweenPlato(gHost,gPort,gUser,gPassword,
+    #                      srcGdbName,tgtGdbName,tgtGAPIUrl,
+    #                      edgeTypeList=edgeTypeList,
+    #                      srcVertexKeynameDict=srcVertexKeynameDict,
+    #                      csv2platoDTypeDict=csv2platoDTypeDict,
+    #                      projectName=projectName)
     
-    # pass
+    downloadGraph(srcClient,"post_skill_school_ianxu","post_tag",
+                  edgeTypeList=["subPost"],
+                  srcVertexKeynameDict={"YunPost":"YunPostName"}
+                  )
