@@ -145,9 +145,9 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
             sysVertexSearchStr="LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttrKey}!='不可能的名字'".format(
-                                                                                                                    nodeType=nodeType,
-                                                                                                                    nodeIdAttrKey=nodeIdAttr
-                                                                                                                )
+                                                                                                                nodeType=nodeType,
+                                                                                                                nodeIdAttrKey=nodeIdAttr
+                                                                                                            )
             # print(sysVertexSearchStr)
             sysIdList=wrapNebula2Df(gClient.execute_query(sysVertexSearchStr)).values.flatten().tolist()
             delVertex(gClient,sysIdList)
@@ -160,6 +160,24 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
             csvDfItem=csvDfItem.loc[csvDfItem[nodeIdAttr].map(lambda nodeAttrVal:existTag(nodeType, nodeIdAttr, nodeAttrVal,gClient)==False)]
             
+            
+            for colItem in attrTypeDict:
+                if attrTypeDict[colItem]=="string":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]="null"
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna("null")
+                elif attrTypeDict[colItem]=="int":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0)
+                elif attrTypeDict[colItem]=="float":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0.0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
+            
         elif vertexAttrProcess=="plus":
             
             nodeItemCInfoDf=csvDfItem.copy(deep=True)
@@ -221,9 +239,42 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                     except ValueError:
                         nodeItemCInfoDf[colItem]=nodeItemCInfoDf[colItem].fillna(fillnaDict[attrTypeDict[colItem]]).astype(platodb2csvDict[attrTypeDict[colItem]])
             csvDfItem=nodeItemCInfoDf
+            
+            for colItem in attrTypeDict:
+                if attrTypeDict[colItem]=="string":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]="null"
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna("null")
+                elif attrTypeDict[colItem]=="int":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0)
+                elif attrTypeDict[colItem]=="float":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0.0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
+                    
         elif vertexAttrProcess=="cover":
-            pass
-        # print("csvDfItem:",csvDfItem.head())
+            
+            for colItem in attrTypeDict:
+                if attrTypeDict[colItem]=="string":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]="null"
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna("null")
+                elif attrTypeDict[colItem]=="int":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0)
+                elif attrTypeDict[colItem]=="float":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0.0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
         
         csvDfItem.to_csv(rawSchemaJson["vertex"][vertexI]["file_path"],index=None)
         rawSchemaJson["vertex"][vertexI]["old_id_col"]=rawSchemaJson["vertex"][vertexI]["id_col"]
@@ -247,6 +298,9 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         csvDfItem[rawSchemaJson["edge"][edgeI]["src_id"]]=csvDfItem[rawSchemaJson["edge"][edgeI]["src_id"]].astype(str).apply(lambda row:srcType+"_"+row if srcType+"_" not in row else row) # 同src的newMadeSysID对应
         csvDfItem[rawSchemaJson["edge"][edgeI]["tgt_id"]]=csvDfItem[rawSchemaJson["edge"][edgeI]["tgt_id"]].astype(str).apply(lambda row:tgtType+"_"+row if tgtType+"_" not in row else row) # 同tgt的newMadeSysID对应
 
+        edgeAttrTypeDf=wrapNebula2Df(gClient.execute_query("DESCRIBE EDGE {}".format(vertexType)))
+        edgeAttrTypeDict=dict(edgeAttrTypeDf.values.tolist())
+
         coverLabel=rawSchemaJson["edge"][edgeI].get("cover_label","escape,escape,cover")
         headEdgeDataProcess,tailEdgeDataProcess,edgeAttrDataProcess=coverLabel.split(",")
 
@@ -297,6 +351,25 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                         csvDfItemRow={srcIdAttr:srcKV,tgtIdAttr:tgtKV}
                         csvDfItemList.append(csvDfItemRow)
             csvDfItem=pd.DataFrame(csvDfItemList)
+            
+            
+            for colItem in edgeAttrTypeDict:
+                if edgeAttrTypeDict[colItem]=="string":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]="null"
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna("null")
+                elif edgeAttrTypeDict[colItem]=="int":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0)
+                elif edgeAttrTypeDict[colItem]=="float":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0.0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
+
         elif edgeAttrDataProcess=="plus":
             htList=json.loads(csvDfItem.to_json(orient="records"))
             newHTList=[]
@@ -330,8 +403,41 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                         newHTItemList[0][keyItem]=htItem[keyItem]
                 newHTList+=newHTItemList
             csvDfItem=pd.DataFrame(newHTList)
+            
+            for colItem in edgeAttrTypeDict:
+                if edgeAttrTypeDict[colItem]=="string":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]="null"
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna("null")
+                elif edgeAttrTypeDict[colItem]=="int":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0)
+                elif edgeAttrTypeDict[colItem]=="float":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0.0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
+                    
         elif edgeAttrDataProcess=="cover":
-            pass
+            for colItem in edgeAttrTypeDict:
+                if edgeAttrTypeDict[colItem]=="string":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]="null"
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna("null")
+                elif edgeAttrTypeDict[colItem]=="int":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0)
+                elif edgeAttrTypeDict[colItem]=="float":
+                    if colItem not in csvDfItem:
+                        csvDfItem[colItem]=0.0
+                    else:
+                        csvDfItem[colItem]=csvDfItem[colItem].fillna(0.0)
 
         csvDfItem.to_csv(rawSchemaJson["edge"][edgeI]["file_path"],index=None)
         if "csv2plato_attr_map" not in rawSchemaJson["edge"][edgeI] or len(rawSchemaJson["edge"][edgeI]["attr_type_map"])==0:
