@@ -164,14 +164,12 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
     rebuildTagIndexErrCode=0
     createEdgeErrCode=0
     schemaJson["vertex"]=schemaJson.get("vertex",[])+[{"node_type":"Alias","old_id_col":"Name","attr_type_map":{"Name":"string"}}]
-    schemaJson["vertex"].pop(-1)
-    schemaJson["edge"]=schemaJson.get("edge",[])+[{"edge_type":"aliasNameOf","attr_type_map":{}}]
-    schemaJson["edge"].pop(-1)
     if "vertex" in schemaJson: # 构建节点schema
         schemaTagList=schemaJson["vertex"]
         for schemaTagItem in schemaTagList:
             nodeType=schemaTagItem["node_type"]
             nodeIdAttr=schemaTagItem["old_id_col"]
+            schemaTagItem["attr_type_map"]={**schemaTagItem["attr_type_map"],**{"sourceName":"string"}}
             nodeAttrStr=",".join([" ".join([attrKey,schemaTagItem["attr_type_map"][attrKey]])+" DEFAULT {}".format(attrTypeNullDict[schemaTagItem["attr_type_map"][attrKey]]) 
                                     for attrKey in schemaTagItem["attr_type_map"]])
             
@@ -196,17 +194,22 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
             )
             rebuildTagIndexReq=graphClient.execute_query(rebuildTagIndexStr)
             rebuildTagIndexErrCode=rebuildTagIndexReq.error_code
-
+    schemaJson["vertex"].pop(-1)
+    
+    schemaJson["edge"]=schemaJson.get("edge",[])+[{"edge_type":"aliasNameOf","attr_type_map":{}}]
     if "edge" in schemaJson: # 构建关系schema
         schemaEdgeList=schemaJson["edge"]
         for schemaEdgeItem in schemaEdgeList:
             edgeType=schemaEdgeItem["edge_type"]
+            schemaEdgeItem={**schemaEdgeItem["attr_type_map"],**{"sourceName":"string"}}
             edgeAttrStr=",".join([" ".join([attrKey,schemaEdgeItem["attr_type_map"][attrKey]])+" DEFAULT {}".format(attrTypeNullDict[schemaEdgeItem["attr_type_map"][attrKey]]) 
-                                    for attrKey in schemaEdgeItem["attr_type_map"]])
+                                    for attrKey in schemaEdgeItem])
 
             createEdgeStr="CREATE EDGE IF NOT EXISTS {}({})".format(edgeType,edgeAttrStr)
             createEdgeReq=graphClient.execute_query(createEdgeStr)
             createEdgeErrCode=createEdgeReq.error_code
+            
+    schemaJson["edge"].pop(-1)
 
     return createTagErrCode,createTagIndexErrCode,rebuildTagIndexErrCode,createEdgeErrCode
             
